@@ -52,7 +52,7 @@ class StandardWidget(Tag):
         placeholder = placeholder.get('placeholder')
         input_type = input_type.get('input_type')
         custom_class = custom_class.get('custom_class')
-        custom_classes = None
+        custom_classes = []
         if custom_class:
             custom_classes = custom_class.split(' ')
         attrs = {}
